@@ -1,5 +1,5 @@
 package Tangerine;
-$Tangerine::VERSION = '0.18';
+$Tangerine::VERSION = '0.19';
 # ABSTRACT: Examine perl files and report dependency metadata
 use 5.010;
 use strict;
@@ -20,7 +20,7 @@ sub new {
         _mode => $args{mode} // 'all',
         _hooks => {
             package => [ qw/package/ ],
-            compile => [ qw/use list prefixedlist anymoose if inline
+            compile => [ qw/use list prefixedlist if inline moduleload
                 moduleruntime mooselike testrequires tests xxx/ ],
             runtime => [ qw/require/ ],
         },
@@ -67,11 +67,12 @@ sub run {
             }
         } @hooks;
     my $children;
+    my $forcetype;
     STATEMENT: for my $statement (@$statements) {
         $children //= [ $statement->schildren ];
         if ($children->[1] &&
             ($children->[1] eq ',' || $children->[1] eq '=>')) {
-            $children = undef;
+            undef $children;
             next STATEMENT
         }
         for my $hook (@hooks) {
@@ -91,11 +92,12 @@ sub run {
                     }
                     $modules->{$k}->line($statement->line_number);
                 }
-                if ($hook->type eq 'package') {
+                my $type = $forcetype // $hook->type;
+                if ($type eq 'package') {
                     $self->package(addoccurence($self->package, $modules));
-                } elsif ($hook->type eq 'compile') {
+                } elsif ($type eq 'compile') {
                     $self->compile(addoccurence($self->compile, $modules));
-                } elsif ($hook->type eq 'runtime') {
+                } elsif ($type eq 'runtime') {
                     $self->runtime(addoccurence($self->runtime, $modules));
                 }
                 if (@{$data->hooks}) {
@@ -112,11 +114,13 @@ sub run {
                 }
                 if (@{$data->children}) {
                     $children = $data->children;
+                    $forcetype = $data->type;
                     redo STATEMENT;
                 }
             }
         }
-        $children = undef;
+        undef $children,
+        undef $forcetype;
     }
     1;
 }
